#import <appkit/View.h>


// RLE.h
// 
// Written by Vince DeMarco 
// 	demarco@cpsc.ucalgary.ca
//
// This program is In the Public Domain. If you make any improvements to this
// program please let me know


@interface RLE:View
{
    id                  thiswindow, thisview;
    int                 xsize, ysize;
    void               *rmap, *gmap, *bmap;
    unsigned char      *r,*g,*b;

    NXZone              *newZone;
    NXRect              temprect;	 // Temp place to store Window Rect
}

- init;
- open:(char *)fileName;
- drawSelf:(const NXRect *)rects :(int)rectCount;
- free;
- (BOOL)isFlipped;
@end

